library(ggplot2)
library(scales)

Sys.setlocale("LC_ALL", "en_US.UTF-8") 

# change background to white, increase font size
theme_set(theme_bw(base_size = 20)) 

setwd("~/Dropbox/2014_google_timelines_project/kgtimelines/FIG")

coverage_with_hxh = read.csv("Rcode/coverage_with_hxh.csv") 
coverage_with_hxh$hxh <- TRUE
coverage_no_hxh = read.csv("Rcode/coverage_no_hxh.csv") 
coverage_no_hxh$hxh <- FALSE
df <- rbind(coverage_with_hxh, coverage_no_hxh)


p <- ggplot(df, aes(x=n_events,y=n_entities_with_at_least_x_events, linetype=hxh, color=hxh)) 
p <- p + geom_line(size=2)
p <- p + scale_y_log10("#Entities w >=X events",
                       breaks = trans_breaks("log10", function(x) 10^x),
                       labels = trans_format("log10", math_format(10^.x)))
p <- p + scale_x_log10("#Events",
                       breaks = trans_breaks("log10", function(x) 10^x),
                       labels = trans_format("log10", math_format(10^.x)))
p <- p + scale_color_discrete(name="",
                    breaks=c(FALSE, TRUE),
                    labels=c("no compound events", "with compound events"))
p <- p + scale_linetype_discrete(name="",
                               breaks=c(FALSE, TRUE),
                               labels=c("no compound events", "with compound events"))
#p <- p + scale_linetype_manual(name="",
#                               values=c(2,1),
#                               breaks=c(FALSE, TRUE),
#                               labels=c("no HxH", "with HxH"))
p <- p + theme(legend.position = c(0.75, 0.85))
p

setwd("~/Dropbox/2014_google_timelines_project/kgtimelines/kdd15/FIG")
ggsave(plot=p, file='results_coverage_geq.pdf', width=8, height=4)


# Need to use cairo pdf for unicode character to work nicely.
library(Cairo)

cairo_pdf("~/Dropbox/2014_google_timelines_project/kgtimelines/kdd15/FIG/results_coverage_new.pdf", width=8, height=4)
p <- ggplot(df, aes(x=n_events,y=n_entities_with_at_least_x_events, linetype=hxh, color=hxh)) 
p <- p + geom_line(size=2)
p <- p + scale_y_log10("#Entities w \u2265x events",
                       breaks = trans_breaks("log10", function(x) 10^x),
                       labels = trans_format("log10", math_format(10^.x)))
p <- p + scale_x_log10("#Events",
                       breaks = trans_breaks("log10", function(x) 10^x),
                       labels = trans_format("log10", math_format(10^.x)))
p <- p + scale_color_discrete(name="",
                              breaks=c(FALSE, TRUE),
                              labels=c("no compound events", "with compound events"))
p <- p + scale_linetype_discrete(name="",
                                 breaks=c(FALSE, TRUE),
                                 labels=c("no compound events", "with compound events"))
#p <- p + scale_linetype_manual(name="",
#                               values=c(2,1),
#                               breaks=c(FALSE, TRUE),
#                               labels=c("no HxH", "with HxH"))
p <- p + theme(legend.position = c(0.75, 0.85))
p
dev.off()